pub struct ParquetStreamingSink<T: ToParquetBatch + Send> { /* private fields */ }Expand description
Parquet streaming sink that buffers items and writes in row groups.
Items are buffered until a row group is full, then written to the Parquet file. This approach provides efficient compression while supporting streaming input.
Type Parameters
T- The type of items to write. Must implementToParquetBatch.
Note
For custom types, implement the ToParquetBatch trait to define how your
data maps to Arrow schema and batches.
Implementations
Sourceimpl<T: ToParquetBatch + Send> ParquetStreamingSink<T>
impl<T: ToParquetBatch + Send> ParquetStreamingSink<T>
Sourcepub fn new(path: PathBuf, row_group_size: usize) -> SynthResult<Self>
pub fn new(path: PathBuf, row_group_size: usize) -> SynthResult<Self>
Sourcepub fn with_defaults(path: PathBuf) -> SynthResult<Self>
pub fn with_defaults(path: PathBuf) -> SynthResult<Self>
Creates a Parquet streaming sink with default row group size (10000).